Package: xcoredata
Type: Package
Title: data package for xcore
Version: 1.17.0
Authors@R: 
    c(person(given = "Maciej",
           family = "Migdał",
           role = c("aut", "cre"),
           email = "mcjmigdal@gmail.com",
           comment = c(ORCID = "0000-0002-8021-7263")),
      person(given = "Bogumił",
           family = "Kaczkowski",
           role = c("aut"),
           email = "mcjmigdal@gmail.com",
           comment = c(ORCID = "0000-0001-6554-5608"))
     )
Description: Provides data to use with xcore package.
Depends: R (>= 4.2)
Imports: ExperimentHub (>= 2.2.0), utils (>= 4.2.0)
Suggests: BiocGenerics (>= 0.40.0), data.table (>= 1.14.2),
        GenomeInfoDb (>= 1.30.0), GenomicRanges (>= 1.46.1), IRanges
        (>= 2.28.0), knitr (>= 1.37), rmarkdown (>= 2.11), Matrix (>=
        1.3.4), stringr (>= 1.4.0), S4Vectors (>= 0.32.3),
        TxDb.Hsapiens.UCSC.hg38.knownGene (>= 3.14.0), xcore
License: GPL-2
Encoding: UTF-8
RoxygenNote: 7.1.2
VignetteBuilder: knitr
biocViews: ExperimentHub, ExperimentData, Homo_sapiens_Data
git_url: https://git.bioconductor.org/packages/xcoredata
git_branch: devel
git_last_commit: e4375ad
git_last_commit_date: 2026-04-28
Repository: Bioconductor 3.24
Date/Publication: 2026-04-30
NeedsCompilation: no
Packaged: 2026-04-30 16:07:47 UTC; biocbuild
Author: Maciej Migdał [aut, cre] (ORCID:
    <https://orcid.org/0000-0002-8021-7263>),
  Bogumił Kaczkowski [aut] (ORCID:
    <https://orcid.org/0000-0001-6554-5608>)
Maintainer: Maciej Migdał <mcjmigdal@gmail.com>
